@@ -1,10 +1,10 @@
 package Apache::Application::Plus ;
-$VERSION = 1.18 ;
+$VERSION = 1.2 ;
+use strict ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
 
-; use strict
 ; use base 'CGI::Application::Plus'
 ; use mod_perl
 ; use constant MP2 => $mod_perl::VERSION >= 1.99
@@ -57,13 +57,15 @@ $VERSION = 1.18 ;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Apache::Application::Plus - Apache/mod_perl integration for CGI::Application::Plus
 
-=head1 VERSION 1.18
+=head1 VERSION 1.2
 
-Included in CGI-Application-Plus 1.18 distribution.
+Included in CGI-Application-Plus 1.2 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -290,3 +292,5 @@ If you need support or if you want just to send me some feedback or request, ple
  2004 by Domizio Demichelis.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as perl itself.
+
+=cut
